==> srun-0.0.5.crate: srun-0.0.5/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.0.5 (2021-10-19)

### New Features

 - <csr-id-51140f3bce3ac47048e9faab5af88441b5077048/> you may now bind local directories
 - <csr-id-2ca5bb973a976c0e841a6dfea7cd508b4d295fc4/> add workdir option

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 3 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - you may now bind local directories ([`51140f3`](https://github.com/git//yxonic/srun.git/commit/51140f3bce3ac47048e9faab5af88441b5077048))
    - add workdir option ([`2ca5bb9`](https://github.com/git//yxonic/srun.git/commit/2ca5bb973a976c0e841a6dfea7cd508b4d295fc4))
    - simplify error handling ([`208f08d`](https://github.com/git//yxonic/srun.git/commit/208f08da7e258122937b184d1ad77040646a42b7))
</details>

## v0.0.4 (2021-10-18)

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 5 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release srun v0.0.4 ([`f3c75cc`](https://github.com/git//yxonic/srun.git/commit/f3c75ccc83748a69c41fa851d9ad2364ecf2cc9b))
    - Release srun v0.0.4 ([`b326665`](https://github.com/git//yxonic/srun.git/commit/b3266654f35fc1ea2cd05bae8e823965e8b21b28))
    - Release srun v0.0.4 ([`f1e9de8`](https://github.com/git//yxonic/srun.git/commit/f1e9de8e9235e8d661a85af9b8f4721be4ce2e46))
    - Release srun v0.0.4 ([`4e5f3d5`](https://github.com/git//yxonic/srun.git/commit/4e5f3d5e5bba99a0026a38aa747c4a235e878bf3))
    - StageSpec ([`69c0c01`](https://github.com/git//yxonic/srun.git/commit/69c0c01a426b46556739b5634662eaad778d7c5a))
</details>

## v0.0.3 (2021-10-18)

### New Features

 - <csr-id-4fbf7933f8a5f97f701a61272f6e1d78f5478cca/> add argument for script file path
 - <csr-id-b44305f3ebee8138e09af50ac4e139191d924a9d/> report exit code if failed
 - <csr-id-0fe4f6945497cfe9e29b1aea93245cd5b80cc4e8/> able to run stage
 - <csr-id-4a05bf2457aae917864bc31fc77337e08e7d0e63/> build image for sandbox run
 - <csr-id-e11a009bd029941e60659eb3743ddc1c52054da5/> add docker and tokio runtime
 - <csr-id-de54ed77bc45df15e99fec23c504214ebfa852a6/> ensure all errors are properly handled in runner

### Bug Fixes

 - <csr-id-9b547c3c645f10bc8f987daaf7551de96300e5c2/> cargo metadata
 - <csr-id-439687f0b6359da2472567eafff31a11ebd1170a/> description
 - <csr-id-daa0b80ce2ae57ed637cc81208e73aa2ee4bb2c3/> add context to main script

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 22 commits contributed to the release over the course of 12 calendar days.
 - 17 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release srun v0.0.3 ([`c62ef1e`](https://github.com/git//yxonic/srun.git/commit/c62ef1e9d17e25e5e0b4409d31b30a79ccc73bb0))
    - smart-release ([`754a051`](https://github.com/git//yxonic/srun.git/commit/754a051b88c05761ce6bd00b3c8b2d8eccbef5f8))
    - clear generic function api with impl ([`9773ec1`](https://github.com/git//yxonic/srun.git/commit/9773ec10496192e92bc607fa838863b4729552a0))
    - cargo metadata ([`9b547c3`](https://github.com/git//yxonic/srun.git/commit/9b547c3c645f10bc8f987daaf7551de96300e5c2))
    - description ([`439687f`](https://github.com/git//yxonic/srun.git/commit/439687f0b6359da2472567eafff31a11ebd1170a))
    - add argument for script file path ([`4fbf793`](https://github.com/git//yxonic/srun.git/commit/4fbf7933f8a5f97f701a61272f6e1d78f5478cca))
    - clearer logging ([`5ce671e`](https://github.com/git//yxonic/srun.git/commit/5ce671e652a0fa6edd1b64dcef7c75f13d0f7840))
    - readme ([`19ae184`](https://github.com/git//yxonic/srun.git/commit/19ae184741eac87136e9d12fc76111f223b031c2))
    - report exit code if failed ([`b44305f`](https://github.com/git//yxonic/srun.git/commit/b44305f3ebee8138e09af50ac4e139191d924a9d))
    - able to run stage ([`0fe4f69`](https://github.com/git//yxonic/srun.git/commit/0fe4f6945497cfe9e29b1aea93245cd5b80cc4e8))
    - prepare for publish ([`1cfe917`](https://github.com/git//yxonic/srun.git/commit/1cfe917bc46200741492e70d055ab49e5c5b1ca1))
    - add context to main script ([`daa0b80`](https://github.com/git//yxonic/srun.git/commit/daa0b80ce2ae57ed637cc81208e73aa2ee4bb2c3))
    - rename to reporter ([`2f57783`](https://github.com/git//yxonic/srun.git/commit/2f577830c8e25faa9fb45eca71f6c7c4a9a8d49f))
    - build image for sandbox run ([`4a05bf2`](https://github.com/git//yxonic/srun.git/commit/4a05bf2457aae917864bc31fc77337e08e7d0e63))
    - build docker image ([`3a608fd`](https://github.com/git//yxonic/srun.git/commit/3a608fd1e0f15e596ddfa6cc92c81cb9f78b0839))
    - extract image id ([`dcd5398`](https://github.com/git//yxonic/srun.git/commit/dcd539868e231dd54857292c0f86529be9af8204))
    - clean up code ([`397e9ce`](https://github.com/git//yxonic/srun.git/commit/397e9ce86220c27c1b875c33979e7041075b927d))
    - fix lint ([`e1d5a2a`](https://github.com/git//yxonic/srun.git/commit/e1d5a2a8d1961736309e86c98714a80ba0fbe15e))
    - add docker and tokio runtime ([`e11a009`](https://github.com/git//yxonic/srun.git/commit/e11a009bd029941e60659eb3743ddc1c52054da5))
    - create licence ([`e20d523`](https://github.com/git//yxonic/srun.git/commit/e20d523c03bd3f331cb87f9b9cd0db42afeb289c))
    - ensure all errors are properly handled in runner ([`de54ed7`](https://github.com/git//yxonic/srun.git/commit/de54ed77bc45df15e99fec23c504214ebfa852a6))
    - initial commit ([`3033b0f`](https://github.com/git//yxonic/srun.git/commit/3033b0f4ec4b1d5f9caa94829972750a432053b7))
</details>

==> srun-0.0.6.crate: srun-0.0.6/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.0.6 (2021-10-19)

### New Features

 - <csr-id-ca02d21d9ae4d0e15f52ab9c1764715b5c51002d/> add asset manager

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - add asset manager ([`ca02d21`](https://github.com/git//yxonic/srun.git/commit/ca02d21d9ae4d0e15f52ab9c1764715b5c51002d))
</details>

## v0.0.5 (2021-10-19)

### New Features

 - <csr-id-51140f3bce3ac47048e9faab5af88441b5077048/> you may now bind local directories
 - <csr-id-2ca5bb973a976c0e841a6dfea7cd508b4d295fc4/> add workdir option

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 4 commits contributed to the release.
 - 3 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release srun v0.0.5 ([`fadf904`](https://github.com/git//yxonic/srun.git/commit/fadf9046db75cc8803ff3db4f87c6381e3d21b2f))
    - you may now bind local directories ([`51140f3`](https://github.com/git//yxonic/srun.git/commit/51140f3bce3ac47048e9faab5af88441b5077048))
    - add workdir option ([`2ca5bb9`](https://github.com/git//yxonic/srun.git/commit/2ca5bb973a976c0e841a6dfea7cd508b4d295fc4))
    - simplify error handling ([`208f08d`](https://github.com/git//yxonic/srun.git/commit/208f08da7e258122937b184d1ad77040646a42b7))
</details>

## v0.0.4 (2021-10-18)

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 5 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release srun v0.0.4 ([`f3c75cc`](https://github.com/git//yxonic/srun.git/commit/f3c75ccc83748a69c41fa851d9ad2364ecf2cc9b))
    - Release srun v0.0.4 ([`b326665`](https://github.com/git//yxonic/srun.git/commit/b3266654f35fc1ea2cd05bae8e823965e8b21b28))
    - Release srun v0.0.4 ([`f1e9de8`](https://github.com/git//yxonic/srun.git/commit/f1e9de8e9235e8d661a85af9b8f4721be4ce2e46))
    - Release srun v0.0.4 ([`4e5f3d5`](https://github.com/git//yxonic/srun.git/commit/4e5f3d5e5bba99a0026a38aa747c4a235e878bf3))
    - StageSpec ([`69c0c01`](https://github.com/git//yxonic/srun.git/commit/69c0c01a426b46556739b5634662eaad778d7c5a))
</details>

## v0.0.3 (2021-10-18)

### New Features

 - <csr-id-4fbf7933f8a5f97f701a61272f6e1d78f5478cca/> add argument for script file path
 - <csr-id-b44305f3ebee8138e09af50ac4e139191d924a9d/> report exit code if failed
 - <csr-id-0fe4f6945497cfe9e29b1aea93245cd5b80cc4e8/> able to run stage
 - <csr-id-4a05bf2457aae917864bc31fc77337e08e7d0e63/> build image for sandbox run
 - <csr-id-e11a009bd029941e60659eb3743ddc1c52054da5/> add docker and tokio runtime
 - <csr-id-de54ed77bc45df15e99fec23c504214ebfa852a6/> ensure all errors are properly handled in runner

### Bug Fixes

 - <csr-id-9b547c3c645f10bc8f987daaf7551de96300e5c2/> cargo metadata
 - <csr-id-439687f0b6359da2472567eafff31a11ebd1170a/> description
 - <csr-id-daa0b80ce2ae57ed637cc81208e73aa2ee4bb2c3/> add context to main script

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 22 commits contributed to the release over the course of 12 calendar days.
 - 17 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release srun v0.0.3 ([`c62ef1e`](https://github.com/git//yxonic/srun.git/commit/c62ef1e9d17e25e5e0b4409d31b30a79ccc73bb0))
    - smart-release ([`754a051`](https://github.com/git//yxonic/srun.git/commit/754a051b88c05761ce6bd00b3c8b2d8eccbef5f8))
    - clear generic function api with impl ([`9773ec1`](https://github.com/git//yxonic/srun.git/commit/9773ec10496192e92bc607fa838863b4729552a0))
    - cargo metadata ([`9b547c3`](https://github.com/git//yxonic/srun.git/commit/9b547c3c645f10bc8f987daaf7551de96300e5c2))
    - description ([`439687f`](https://github.com/git//yxonic/srun.git/commit/439687f0b6359da2472567eafff31a11ebd1170a))
    - add argument for script file path ([`4fbf793`](https://github.com/git//yxonic/srun.git/commit/4fbf7933f8a5f97f701a61272f6e1d78f5478cca))
    - clearer logging ([`5ce671e`](https://github.com/git//yxonic/srun.git/commit/5ce671e652a0fa6edd1b64dcef7c75f13d0f7840))
    - readme ([`19ae184`](https://github.com/git//yxonic/srun.git/commit/19ae184741eac87136e9d12fc76111f223b031c2))
    - report exit code if failed ([`b44305f`](https://github.com/git//yxonic/srun.git/commit/b44305f3ebee8138e09af50ac4e139191d924a9d))
    - able to run stage ([`0fe4f69`](https://github.com/git//yxonic/srun.git/commit/0fe4f6945497cfe9e29b1aea93245cd5b80cc4e8))
    - prepare for publish ([`1cfe917`](https://github.com/git//yxonic/srun.git/commit/1cfe917bc46200741492e70d055ab49e5c5b1ca1))
    - add context to main script ([`daa0b80`](https://github.com/git//yxonic/srun.git/commit/daa0b80ce2ae57ed637cc81208e73aa2ee4bb2c3))
    - rename to reporter ([`2f57783`](https://github.com/git//yxonic/srun.git/commit/2f577830c8e25faa9fb45eca71f6c7c4a9a8d49f))
    - build image for sandbox run ([`4a05bf2`](https://github.com/git//yxonic/srun.git/commit/4a05bf2457aae917864bc31fc77337e08e7d0e63))
    - build docker image ([`3a608fd`](https://github.com/git//yxonic/srun.git/commit/3a608fd1e0f15e596ddfa6cc92c81cb9f78b0839))
    - extract image id ([`dcd5398`](https://github.com/git//yxonic/srun.git/commit/dcd539868e231dd54857292c0f86529be9af8204))
    - clean up code ([`397e9ce`](https://github.com/git//yxonic/srun.git/commit/397e9ce86220c27c1b875c33979e7041075b927d))
    - fix lint ([`e1d5a2a`](https://github.com/git//yxonic/srun.git/commit/e1d5a2a8d1961736309e86c98714a80ba0fbe15e))
    - add docker and tokio runtime ([`e11a009`](https://github.com/git//yxonic/srun.git/commit/e11a009bd029941e60659eb3743ddc1c52054da5))
    - create licence ([`e20d523`](https://github.com/git//yxonic/srun.git/commit/e20d523c03bd3f331cb87f9b9cd0db42afeb289c))
    - ensure all errors are properly handled in runner ([`de54ed7`](https://github.com/git//yxonic/srun.git/commit/de54ed77bc45df15e99fec23c504214ebfa852a6))
    - initial commit ([`3033b0f`](https://github.com/git//yxonic/srun.git/commit/3033b0f4ec4b1d5f9caa94829972750a432053b7))
</details>
